Rev 6333: (jelmer) Always pass in the tree path to Tree methods when exporting. in file:///srv/pqm.bazaar-vcs.org/archives/thelove/bzr/%2Btrunk/

Patch Queue Manager pqm at pqm.ubuntu.com
Thu Dec 1 11:27:50 UTC 2011


At file:///srv/pqm.bazaar-vcs.org/archives/thelove/bzr/%2Btrunk/

------------------------------------------------------------
revno: 6333 [merge]
revision-id: pqm at pqm.ubuntu.com-20111201112749-5b4e6ae2utuclht2
parent: pqm at pqm.ubuntu.com-20111201023846-zw38oqm28xr25trs
parent: jelmer at samba.org-20111130200216-aoju21pdl20d1gkd
committer: Patch Queue Manager <pqm at pqm.ubuntu.com>
branch nick: +trunk
timestamp: Thu 2011-12-01 11:27:49 +0000
message:
  (jelmer) Always pass in the tree path to Tree methods when exporting.
   (Jelmer Vernooij)
modified:
  bzrlib/export/__init__.py      __init__.py-20051114235828-1ba62cb4062304e6
  bzrlib/export/dir_exporter.py  dir_exporter.py-20051114235828-b51397f56bc7b117
  bzrlib/export/tar_exporter.py  tar_exporter.py-20051114235828-1f6349a2f090a5d0
  bzrlib/export/zip_exporter.py  zip_exporter.py-20051114235828-8f57f954fba6497e
=== modified file 'bzrlib/export/__init__.py'
--- a/bzrlib/export/__init__.py	2011-07-08 23:38:46 +0000
+++ b/bzrlib/export/__init__.py	2011-11-30 20:02:16 +0000
@@ -195,6 +195,8 @@
     :param tree: A tree object.
     :param subdir: None or the path of an entry to start exporting from.
     :param skip_special: Whether to skip .bzr files.
+    :return: iterator over tuples with final path, tree path and inventory
+        entry for each entry to export
     """
     if subdir == '':
         subdir = None
@@ -221,7 +223,7 @@
         if not tree.has_filename(path):
             continue
 
-        yield final_path, entry
+        yield final_path, path, entry
 
 
 register_lazy_exporter(None, [], 'bzrlib.export.dir_exporter',

=== modified file 'bzrlib/export/dir_exporter.py'
--- a/bzrlib/export/dir_exporter.py	2011-07-04 21:55:35 +0000
+++ b/bzrlib/export/dir_exporter.py	2011-11-30 20:02:16 +0000
@@ -52,15 +52,15 @@
     # Note in the case of revision trees, this does trigger a double inventory
     # lookup, hopefully it isn't too expensive.
     to_fetch = []
-    for dp, ie in _export_iter_entries(tree, subdir):
+    for dp, tp, ie in _export_iter_entries(tree, subdir):
         fullpath = osutils.pathjoin(dest, dp)
         if ie.kind == "file":
-            to_fetch.append((ie.file_id, (dp, tree.is_executable(ie.file_id))))
+            to_fetch.append((ie.file_id, (dp, tp, ie.file_id)))
         elif ie.kind == "directory":
             os.mkdir(fullpath)
         elif ie.kind == "symlink":
             try:
-                symlink_target = tree.get_symlink_target(ie.file_id)
+                symlink_target = tree.get_symlink_target(ie.file_id, tp)
                 os.symlink(symlink_target, fullpath)
             except OSError, e:
                 raise errors.BzrError(
@@ -74,11 +74,11 @@
     # The data returned here can be in any order, but we've already created all
     # the directories
     flags = os.O_CREAT | os.O_TRUNC | os.O_WRONLY | getattr(os, 'O_BINARY', 0)
-    for (relpath, executable), chunks in tree.iter_files_bytes(to_fetch):
+    for (relpath, treepath, file_id), chunks in tree.iter_files_bytes(to_fetch):
         fullpath = osutils.pathjoin(dest, relpath)
         # We set the mode and let the umask sort out the file info
         mode = 0666
-        if executable:
+        if tree.is_executable(file_id, treepath):
             mode = 0777
         out = os.fdopen(os.open(fullpath, flags, mode), 'wb')
         try:
@@ -88,11 +88,7 @@
         if force_mtime is not None:
             mtime = force_mtime
         else:
-            if subdir is None:
-                file_id = tree.path2id(relpath)
-            else:
-                file_id = tree.path2id(osutils.pathjoin(subdir, relpath))
-            mtime = tree.get_file_mtime(file_id, relpath)
+            mtime = tree.get_file_mtime(file_id, treepath)
         os.utime(fullpath, (mtime, mtime))
 
         yield

=== modified file 'bzrlib/export/tar_exporter.py'
--- a/bzrlib/export/zip_exporter.py	2011-07-04 21:55:35 +0000
+++ b/bzrlib/export/zip_exporter.py	2011-11-30 20:02:16 +0000
@@ -55,7 +55,7 @@
         dest = sys.stdout
     zipf = zipfile.ZipFile(dest, "w", compression)
     try:
-        for dp, ie in _export_iter_entries(tree, subdir):
+        for dp, tp, ie in _export_iter_entries(tree, subdir):
             file_id = ie.file_id
             mutter("  export {%s} kind %s to %s", file_id, ie.kind, dest)
 
@@ -64,7 +64,7 @@
             if force_mtime is not None:
                 mtime = force_mtime
             else:
-                mtime = tree.get_file_mtime(ie.file_id, dp)
+                mtime = tree.get_file_mtime(ie.file_id, tp)
             date_time = time.localtime(mtime)[:6]
             filename = osutils.pathjoin(root, dp).encode('utf8')
             if ie.kind == "file":
@@ -73,7 +73,7 @@
                             date_time=date_time)
                 zinfo.compress_type = compression
                 zinfo.external_attr = _FILE_ATTR
-                content = tree.get_file_text(file_id)
+                content = tree.get_file_text(file_id, tp)
                 zipf.writestr(zinfo, content)
             elif ie.kind == "directory":
                 # Directories must contain a trailing slash, to indicate
@@ -91,7 +91,7 @@
                             date_time=date_time)
                 zinfo.compress_type = compression
                 zinfo.external_attr = _FILE_ATTR
-                zipf.writestr(zinfo, tree.get_symlink_target(file_id))
+                zipf.writestr(zinfo, tree.get_symlink_target(file_id, tp))
             yield
 
         zipf.close()




More information about the bazaar-commits mailing list
--- a/bzrlib/export/tar_exporter.py	2011-07-21 07:08:05 +0000
+++ b/bzrlib/export/tar_exporter.py	2011-11-30 20:02:16 +0000
@@ -28,15 +28,13 @@
 from bzrlib.export import _export_iter_entries
 
 
-def prepare_tarball_item(tree, root, final_path, entry, force_mtime=None):
+def prepare_tarball_item(tree, root, final_path, tree_path, entry, force_mtime=None):
     """Prepare a tarball item for exporting
 
     :param tree: Tree to export
-
     :param final_path: Final path to place item
-
+    :param tree_path: Path for the entry in the tree
     :param entry: Entry to export
-
     :param force_mtime: Option mtime to force, instead of using tree
         timestamps.
 
@@ -47,10 +45,10 @@
     if force_mtime is not None:
         item.mtime = force_mtime
     else:
-        item.mtime = tree.get_file_mtime(entry.file_id, final_path)
+        item.mtime = tree.get_file_mtime(entry.file_id, tree_path)
     if entry.kind == "file":
         item.type = tarfile.REGTYPE
-        if tree.is_executable(entry.file_id):
+        if tree.is_executable(entry.file_id, tree_path):
             item.mode = 0755
         else:
             item.mode = 0644
@@ -58,7 +56,7 @@
         # the tarfile contract, which wants the size of the file up front.  We
         # want to make sure it doesn't change, and we need to read it in one
         # go for content filtering.
-        content = tree.get_file_text(entry.file_id)
+        content = tree.get_file_text(entry.file_id, tree_path)
         item.size = len(content)
         fileobj = StringIO.StringIO(content)
     elif entry.kind == "directory":
@@ -71,7 +69,7 @@
         item.type = tarfile.SYMTYPE
         item.size = 0
         item.mode = 0755
-        item.linkname = tree.get_symlink_target(entry.file_id)
+        item.linkname = tree.get_symlink_target(entry.file_id, tree_path)
         fileobj = None
     else:
         raise errors.BzrError("don't know how to export {%s} of kind %r"
@@ -97,9 +95,9 @@
         timestamps.
     """
     try:
-        for final_path, entry in _export_iter_entries(tree, subdir):
+        for final_path, tree_path, entry in _export_iter_entries(tree, subdir):
             (item, fileobj) = prepare_tarball_item(
                 tree, root, final_path, entry, force_mtime)
             ball.addfile(item, fileobj)
             yield
     finally:
@@ -97,9 +95,9 @@
             (item, fileobj) = prepare_tarball_item(
-                tree, root, final_path, entry, force_mtime)
+                tree, root, final_path, tree_path, entry, force_mtime)
             ball.addfile(item, fileobj)
             yield

=== modified file 'bzrlib/export/zip_exporter.py'